@@ -181,14 +181,7 @@ function aimCmdNewBrowser(url)
     Browser_pref = null;
 	}
 
-	if (Browser_pref.getBoolPref("network.protocols.useSystemDefaults"))
-  {
-	  var uri = Components.classes["@mozilla.org/network/standard-url;1"].createInstance(Components.interfaces.nsIURI); 
-		uri.spec=url;
-		aimAdminManager().LoadDefaultBrowser(uri);
-	}
-	else
-		window.openDialog( "chrome://navigator/content/navigator.xul", "_blank", "chrome,all,dialog=no", url);
+	window.openDialog( "chrome://navigator/content/navigator.xul", "_blank", "chrome,all,dialog=no", url);
 }
 
 
