@@ -15,7 +15,7 @@ var AddressAutoCompleteListener = {
 
 function aimAutoCompleteObject()
 {
-	var pIIMManager = aimGetIMManager();
+	var pIIMManager = aimManager();
 	if(pIIMManager)
 		return pIIMManager.QueryInterface(Components.interfaces.nsIAutoCompleteSession);
 	else
