@@ -259,6 +259,20 @@ function chatContentOnWinLoad()
   document.getElementById("insertTOC").setAttribute("hidden", true);
   document.getElementById("insertMenuSeparator").setAttribute("hidden", true);
   document.getElementById("insertBreakAll").setAttribute("hidden", true);
+
+  // style the conversation log box
+  var logdoc = document.getElementById("LogWnd").contentDocument;
+  if (logdoc)
+  {
+    logdoc.close();
+    logdoc.open();
+    logdoc.write('<html><head>');
+    logdoc.write('<link rel="important stylesheet" href="chrome://communicator/skin/smileys.css">');
+    logdoc.write('</head><body></body></html>');
+    logdoc.close();
+  }
+  else
+    dump("chatContentOnWinLoad: couldn't style log window");
 }
 
 function composeKeyPress(event)
