@@ -3,7 +3,7 @@ pref("browser.startup.homepage", "chrome://navigator-region/locale/region.proper
 pref("keyword.enabled", true);
 pref("profile.confirm_automigration",false);
 pref("general.useragent.vendor", "Netscape");
-pref("general.useragent.vendorSub", "7.1");
+pref("general.useragent.vendorSub", "7.2");
 pref("general.license.accepted", false);
 pref("browser.throbber.url","chrome://navigator-region/locale/region.properties");
 pref("editor.throbber.url","chrome://editor-region/locale/region-ns.properties");
@@ -38,8 +38,11 @@ pref("browser.webmailcookie.domain", "chrome://navigator-region/locale/region.pr
 pref("browser.related.provider", "http://info.netscape.com/fwd/siduswrl/http://www-rl.netscape.com/wtgn?");
 
 // sidebar customization overring for commercial
-pref("sidebar.customize.directory.url", "http://home.netscape.com/bookmark/7_1/sbdirectorychrome.html");
-pref("sidebar.customize.more_panels.url", "http://home.netscape.com/bookmark/7_1/sbdirectorycustom.html");
+pref("sidebar.customize.directory.url", "http://home.netscape.com/bookmark/7_2/sbdirectorychrome.html");
+pref("sidebar.customize.more_panels.url", "http://home.netscape.com/bookmark/7_2/sbdirectorycustom.html");
+
+// Bookmarks pref
+pref("browser.toolbars.showbutton.bookmarks", false);
 
 // sidebar button pref
 pref("browser.toolbars.showbutton.sidebar", true);
@@ -47,11 +50,14 @@ pref("browser.toolbars.showbutton.sidebar", true);
 // toolbar search button pref
 pref("browser.toolbars.showbutton.netscapesearch", true);
 
+// urlbar search button pref
+pref("browser.toolbars.showbutton.search", false);
+
 // shopping button pref
 pref("browser.toolbars.showbutton.netscapeshop", false);
 
 // radio button pref
-pref("browser.toolbars.showbutton.netscaperadio", true);
+pref("browser.toolbars.showbutton.netscaperadio", false);
 
 // MyNetscape button pref
 pref("browser.toolbars.showbutton.mynetscape", true);
@@ -104,3 +110,6 @@ pref("accessibility.typeaheadfind.autostart", false);
 
 // turn off pinging any server on startup from the js debugger
 pref("extensions.venkman.permitStartupHit", false);
+
+// add netscape sites to the XPInstall default whitelist
+pref("xpinstall.whitelist.add", "mozilla.org, mozdev.org, netscape.com, aol.com");
